@@ -79,7 +79,7 @@ def main():
 
         # Split into function and arguments
         func = args['func']
-        del(args['func'])
+        del args['func']
 
         # Call the selected function with the parsed arguments
         func(**args)
@@ -561,7 +561,7 @@ def install_windows():
         with open(output, 'w') as f:
             p.set_output_stream(f)
             p.process(source, varmap)
-        del(p)
+        del p
 
         # Install
         menuinst.install(output)
@@ -978,10 +978,15 @@ def run(source, debug_sg, debug_wg, debug_sc, debug_sm, debug_sp):
     import myokit
 
     # Debug modes
+    # Show generated code
     myokit.DEBUG_SG = myokit.DEBUG_SG or debug_sg
+    # Write generated code to file
     myokit.DEBUG_WG = myokit.DEBUG_WG or debug_wg
+    # Show compiler output
     myokit.DEBUG_SC = myokit.DEBUG_SC or debug_sc
+    # Show messages when running compiled code
     myokit.DEBUG_SM = myokit.DEBUG_SM or debug_sm
+    # Show profiling information when running compiled code
     myokit.DEBUG_SP = myokit.DEBUG_SP or debug_sp
 
     # Read mmt file
@@ -1928,7 +1933,7 @@ def test_mmt_files(path):
                 except Exception:
                     error = 1
                     print(traceback.format_exc())
-                del(m, p, x)
+                del m, p, x
             except Exception:
                 print('Unable to load.')
                 print(traceback.format_exc())
@@ -2118,7 +2123,7 @@ def video(src, key, dst, fps, grow, colormap):
         print('DataBlock reading failed\n: ' + str(e))
         sys.exit(1)
     finally:
-        del(reporter)
+        del reporter
 
     # Don't load empty files
     if data.len2d() < 1:
