@@ -14,11 +14,12 @@ from __future__ import print_function, unicode_literals
 # before this method was called.
 import myokit
 
-# Load libraries
-import os
-import sys
+# Load standard library modules
 import logging
+import os
 import platform
+import sys
+import warnings
 
 # ConfigParser in Python 2 and 3
 try:
@@ -48,23 +49,33 @@ def _create(path):
         '# This file can be used to set global configuration options for'
         ' Myokit.')
 
+    # Compatibility settings
+    config.add_section('compatibility')
+    config.set(
+        'compatibility',
+        '# Optional settings to make Myokit work on tricky systems.')
+    config.set('compatibility', '# Don\'t capture compiler output.')
+    config.set('compatibility', '#no_capture = True')
+    config.set('compatibility', '# Don\'t use the file-descriptor method.')
+    config.set('compatibility', '#no_fd_capture = True')
+
     # Date format
     config.add_section('time')
     config.set('time', '# Date format used throughout Myokit')
-    config.set('time', '# Format should be acceptable for time.strftime')
+    config.set('time', '# The format should be acceptable for time.strftime')
     config.set('time', 'date_format', myokit.DATE_FORMAT)
     config.set('time', '# Time format used throughout Myokit')
-    config.set('time', '# Format should be acceptable for time.strftime')
-    config.set('time', '# Format should be acceptable for time.strftime')
+    config.set('time', '# The format should be acceptable for time.strftime')
     config.set('time', 'time_format', myokit.TIME_FORMAT)
 
     # GUI Backend
     config.add_section('gui')
     config.set('gui', '# Backend to use for graphical user interface.')
-    config.set('gui', '# Valid options are "pyqt5", "pyqt4" or "pyside".')
+    config.set('gui', '# Valid options are pyqt5, pyqt4, pyside2 and pyside.')
     config.set('gui', '# Leave unset for automatic selection.')
     config.set('gui', '#backend = pyqt5')
     config.set('gui', '#backend = pyqt4')
+    config.set('gui', '#backend = pyside2')
     config.set('gui', '#backend = pyside')
 
     # Locations of sundials library
@@ -122,7 +133,7 @@ def _create(path):
         config.set('opencl', 'lib', ';'.join([
             c64 + 'Intel\\OpenCL SDK\\6.3\\lib\\x64',
             c64 + 'AMD APP SDK\\2.9\\bin\\x64',
-            c64 + 'NVIDIA GPU Computing Toolkit\CUDA\\v10.1\\lib\\x64',
+            c64 + 'NVIDIA GPU Computing Toolkit\CUDA\\v11.8\\lib\\x64',
         ]))
     else:
         # Linux and mac
@@ -144,7 +155,7 @@ def _create(path):
         config.set('opencl', 'inc', ';'.join([
             c64 + 'Intel\\OpenCL SDK\\6.3\\include',
             c64 + 'AMD APP SDK\\2.9\\include',
-            c64 + 'NVIDIA GPU Computing Toolkit\\CUDA\\v10.1\\include',
+            c64 + 'NVIDIA GPU Computing Toolkit\\CUDA\\v11.8\\include',
         ]))
     else:
         # Linux and mac
@@ -193,7 +204,7 @@ def _load():
                     + str(1 + i) + ', character ' + str(x) + ', semicolons (;)'
                     + ' must not be preceded by whitespace: ```'
                     + line.strip() + '```.')
-        del(lines, inline_comment)
+        del lines, inline_comment
 
     # Create the config parser (no value allows comments)
     config = ConfigParser(allow_no_value=True)
@@ -204,6 +215,30 @@ def _load():
     # Parse the config file
     config.read(path)
 
+    # Compatibility options
+    if config.has_option('compatibility', 'no_capture'):
+        x = config.get('compatibility', 'no_capture').strip().lower()
+        if x == 'true':
+            myokit.COMPAT_NO_CAPTURE = True
+        elif x == 'false':
+            myokit.COMPAT_NO_CAPTURE = False
+        elif x != '':
+            warnings.warn(
+                'Invalid setting in myokit.ini. Expected values for no_capture'
+                ' are true, false, or not set (empty), but got: ' + x)
+
+    if config.has_option('compatibility', 'no_fd_capture'):
+        x = config.get('compatibility', 'no_fd_capture').strip().lower()
+        if x == 'true':
+            myokit.COMPAT_NO_FD_CAPTURE = True
+        elif x == 'false':
+            myokit.COMPAT_NO_FD_CAPTURE = False
+        elif x != '':
+            warnings.warn(
+                'Invalid setting in myokit.ini. Expected values for'
+                ' no_fd_capture are true, false, or not set (empty), but got: '
+                + x)
+
     # Date format
     if config.has_option('time', 'date_format'):
         x = config.get('time', 'date_format')
@@ -239,8 +274,10 @@ def _load():
             myokit.FORCE_PYQT5 = False
             myokit.FORCE_PYSIDE = False
             myokit.FORCE_PYSIDE2 = True
-        #else:
-        # If empty or invalid, don't adjust the settings!
+        elif x != '':
+            warnings.warn(
+                'Invalid setting in myokit.ini. Expected values for backend'
+                ' are pyqt, pyqt4, pyqt5, pyside, or pyside2. Got: ' + x)
 
     # Sundials libraries, header files, and version
     if config.has_option('sundials', 'lib'):
