@@ -15,7 +15,7 @@ __release__ = True
 #    incompatibility
 #  - Changes to revision indicate bugfixes, tiny new features
 #  - There is no significance to odd/even numbers
-__version_tuple__ = 1, 33, 7
+__version_tuple__ = 1, 33, 8
 
 # String version of the version number
 __version__ = '.'.join([str(x) for x in __version_tuple__])
@@ -25,4 +25,4 @@ if not __release__:  # pragma: no cover
 
 # Don't expose x on Python2
 if sys.hexversion < 0x03000000:  # pragma: no python 3 cover
-    del(x)
+    del x
