@@ -198,7 +198,7 @@ class CellMLParser(object):
         except myokit.formats.mathml.MathMLError as e:
             raise CellMLParsingError(str(e))
         finally:
-            del(self._ns, self._ids, self._vois)
+            del self._ns, self._ids, self._vois
 
     def parse_file(self, path):
         """
@@ -834,7 +834,7 @@ class CellMLParser(object):
             if fresh:
                 for name in fresh:
                     resolved.add(name)
-                    del(unresolved[name])
+                    del unresolved[name]
                 for name, deps in unresolved.items():
                     deps.difference_update(fresh)
             else:
