@@ -477,7 +477,7 @@ class LibGuessTest(unittest.TestCase):
         # Alternatively, use oxmeta annotation
         x.meta['oxmeta'] = 'membrane_voltage'
         self.assertEqual(guess.membrane_potential(m), x)
-        del(x.meta['oxmeta'])
+        del x.meta['oxmeta']
         self.assertNotEqual(guess.membrane_potential(m), x)
 
     def test_membrane_potential_2(self):
@@ -737,7 +737,7 @@ class LibGuessTest(unittest.TestCase):
         # Alternatively, use oxmeta annotation
         x.meta['oxmeta'] = 'membrane_stimulus_current'
         self.assertEqual(guess.stimulus_current(m), x)
-        del(x.meta['oxmeta'])
+        del x.meta['oxmeta']
         self.assertNotEqual(guess.stimulus_current(m), x)
 
     def test_stimulus_current_2(self):
@@ -902,7 +902,7 @@ class LibGuessTest(unittest.TestCase):
         self.assertEqual(i['period'], m.get('c.a'))
         self.assertEqual(i['offset'], m.get('c.b'))
         self.assertIsNone(i['amplitude_expression'])
-        del(m.get('c.t').meta['oxmeta'])
+        del m.get('c.t').meta['oxmeta']
         i = guess.stimulus_current_info(m)
         self.assertEqual(i['current'], m.get('c.t'))
         self.assertEqual(i['amplitude'], m.get('c.v'))
